Index: handler/mac/crash_report_upload_thread.cc |
diff --git a/handler/mac/crash_report_upload_thread.cc b/handler/mac/crash_report_upload_thread.cc |
index a4e4607d0c57bf4d6c96a1ad85e9bde5b0b02e93..5333c78d180e02d476dfb4a3434515220363e0a2 100644 |
--- a/handler/mac/crash_report_upload_thread.cc |
+++ b/handler/mac/crash_report_upload_thread.cc |
@@ -226,9 +226,11 @@ void CrashReportUploadThread::ProcessPendingReport( |
Settings* const settings = database_->GetSettings(); |
bool uploads_enabled; |
- if (!settings->GetUploadsEnabled(&uploads_enabled) || !uploads_enabled) { |
- // If uploads are disabled or the upload-enabled state can’t be determined, |
- // don’t attempt to upload the new report. |
+ if (!settings->GetUploadsEnabled(&uploads_enabled) || |
+ !uploads_enabled || |
+ url_.empty()) { |
+ // If the upload-enabled state can’t be determined, uploads are disabled, or |
+ // there’s no URL to upload to, don’t attempt to upload the new report. |
database_->SkipReportUpload(report.uuid); |
return; |
} |